{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#clean_vcf.cwl",
            "label": "clean-vcf",
            "doc": "This tool will clean a VCF for use in the OxoG workflow.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#clean_vcf.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/clean_vcf.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cleaned.vcf"
                    },
                    "id": "#clean_vcf.cwl/clean-vcf/clean_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#normalize.cwl",
            "label": "normalize",
            "doc": "This tool will normalize an INDEL VCF using bcf-tools norm.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#normalize.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#normalize.cwl/ref",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".fai"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#normalize.cwl/normalized-vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.normalized.vcf.gz"
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/normalize.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#pass-filter.cwl",
            "label": "pass-filter",
            "doc": "This tool will pass-filter a VCF.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#pass-filter.cwl/vcfdir",
                    "type": "Directory",
                    "doc": "The directory containing the files"
                },
                {
                    "id": "#pass-filter.cwl/filesToFilter",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The names of the files that will actually be filtered"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.pass-filtered.vcf.gz"
                    },
                    "id": "#pass-filter.cwl/pass-filter/output"
                }
            ],
            "arguments": [
                "$(inputs.vcfdir.path)",
                "$(inputs.filesToFilter)"
            ],
            "baseCommand": "/opt/oxog_scripts/pass_filter.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "Workflow",
            "doc": "This workflow will perform preprocessing steps on VCFs for the OxoG/Variantbam/Annotation workflow.\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/mergedVcfs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/normalizedVcfs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/extractedSnvs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/cleanedVcfs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\n/**\n * Filters an array of files. Returns an array that only contains files that contain \"indel\" in their name.\n * @param inArr - the array.\n * @return a filtered array - it will only contain files whose names contain the string \"indel\".\n */\nfunction filterForIndels(inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length ; i++)\n\t{\n\t\tif (inArr[i].basename.indexOf(\"indel\") >= 0)\n\t\t{\n\t\t\tarr.push(inArr[i]);\n\t\t}\n\t}\n\treturn arr;\n}\n\n/**\n * This function will filter an array of files and select only files that match\n * workflowName and vcfType.\n * @param workflowName - the name of the workflow to filter for.\n * @param vcfType - the type of VCF (snv, indel, etc...)\n * @param inArr - an array of files (File[]) to search through.\n * @return an array that has been filtered.\n */\nfunction filterFor(workflowName, vcfType, inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length; i++)\n\t{\n\t\tif (typeof(inArr[i]) == \"string\") //(\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t{\n\t\t\tif (inArr[i].indexOf(workflowName) >= 0 && inArr[i].indexOf(vcfType) >= 0)\n\t\t\t{\n\t\t\t\tarr.push(inArr[i])\n\t\t\t}\n\t\t}\n\t\telse\n\t\t{\n\t\t\tif (\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t\t{\n\t\t\t\tif (inArr[i].basename.indexOf(workflowName) >= 0 && inArr[i].basename.indexOf(vcfType) >= 0)\n\t\t\t\t{\n\t\t\t\t\tarr.push(inArr[i])\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t}\n\treturn arr;\n}\n"
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/vcfdir",
                    "type": "Directory",
                    "doc": "The directory where the files are"
                },
                {
                    "id": "#main/filesToPreprocess",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The files to process"
                },
                {
                    "id": "#main/ref",
                    "type": "File",
                    "doc": "Reference file, used for normalized INDELs"
                },
                {
                    "id": "#main/out_dir",
                    "type": "string",
                    "doc": "The name of the output directory"
                }
            ],
            "outputs": [
                {
                    "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                    "outputSource": "#main/populate_output_record/output_record",
                    "id": "#main/preprocessedFiles"
                }
            ],
            "steps": [
                {
                    "doc": "Clean the VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/clean/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean/clean_vcf"
                    ],
                    "id": "#main/clean"
                },
                {
                    "doc": "Filters the input list and selects the INDEL VCFs.",
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/filter_for_indel/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_for_indel/out_vcf"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/403becaf-2133-4530-a0dc-71298b2ee9d4/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/403becaf-2133-4530-a0dc-71298b2ee9d4/out_vcf"
                            }
                        ],
                        "expression": "$({ out_vcf: filterForIndels(inputs.in_vcf) })\n",
                        "id": "#main/filter_for_indel/403becaf-2133-4530-a0dc-71298b2ee9d4"
                    },
                    "id": "#main/filter_for_indel"
                },
                {
                    "doc": "Normalize the INDEL VCFs.",
                    "run": "#normalize.cwl",
                    "scatter": "#main/normalize/vcf",
                    "in": [
                        {
                            "source": "#main/ref",
                            "id": "#main/normalize/ref"
                        },
                        {
                            "source": "#main/filter_for_indel/out_vcf",
                            "id": "#main/normalize/vcf"
                        }
                    ],
                    "out": [
                        "#main/normalize/normalized-vcf"
                    ],
                    "id": "#main/normalize"
                },
                {
                    "doc": "Filter out non-PASS lines from the VCFs in filesToProcess.",
                    "in": [
                        {
                            "source": [
                                "#main/filesToPreprocess"
                            ],
                            "valueFrom": "${\n    var VCFs = []\n    for (var i in self)\n    {\n        if (self[i].toLowerCase().indexOf(\"muse\") == -1)\n        {\n            VCFs.push(self[i]);\n        }\n    }\n    return VCFs;\n}\n",
                            "id": "#main/pass_filter/filesToFilter"
                        },
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/pass_filter/vcfdir"
                        }
                    ],
                    "run": "#pass-filter.cwl",
                    "out": [
                        "#main/pass_filter/output"
                    ],
                    "id": "#main/pass_filter"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/populate_output_record/normalizedVcfs"
                        }
                    ],
                    "out": [
                        "#main/populate_output_record/output_record"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/ecda4532-6734-4396-89d4-a6f1f712b57e/normalizedVcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                                "id": "#main/populate_output_record/ecda4532-6734-4396-89d4-a6f1f712b57e/output_record"
                            }
                        ],
                        "expression": "$(\n    {output_record: {\n        \"normalizedVcfs\": inputs.normalizedVcfs\n    }}\n)\n",
                        "id": "#main/populate_output_record/ecda4532-6734-4396-89d4-a6f1f712b57e"
                    },
                    "id": "#main/populate_output_record"
                }
            ],
            "id": "#main",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        }
    ],
    "cwlVersion": "v1.0"
}
